@@ -1,6 +1,6 @@
 /*
     ras - Redundant Archive System
-    Copyright (C) 1998  Nick Cleaton
+    Copyright (C) 1999  Nick Cleaton
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,9 +14,9 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 
-    Nick Cleaton <nc@dial.pipex.com>
+    Nick Cleaton <nick@cleaton.net>
 */
 /*
 
